@@ -1,9 +1,9 @@
-/*  $Id: data.h,v 1.3 1998/06/21 09:55:05 rsmith Exp $
+/*  $Id: data.h,v 1.4 2000/01/01 21:26:37 rsmith Exp $
  * --------------------------------------------------------------------
  * This file is part of xnetload, a program to monitor network traffic,
  * and display it in an X window.
  *
- * Copyright (C) 1997, 1998  R.F. Smith <rsmith@xs4all.nl>
+ * Copyright (C) 1997, 1999  R.F. Smith <rsmith@xs4all.nl>
  *
  * You can contact the author at the following address:
  *      email: rsmith@xs4all.nl
@@ -28,6 +28,18 @@
  * 
  * --------------------------------------------------------------------
  * $Log: data.h,v $
+ * Revision 1.4  2000/01/01 21:26:37  rsmith
+ * Release 1.7.1b3
+ *
+ * Revision 1.3  1999/12/27 22:16:45  rsmith
+ * Fixed bugs for release 1.7.0b1
+ *
+ * Revision 1.2  1999/12/27 18:54:22  rsmith
+ * Remove references to `where' (for 1.7.0 release).
+ *
+ * Revision 1.1  1999/05/09 16:38:31  rsmith
+ * Put back into RCS.
+ *
  * Revision 1.3  1998/06/21 09:55:05  rsmith
  * - Added Tony's patch for IP-acounting rules.
  *
@@ -52,16 +64,12 @@ typedef struct {
 } count_t;
 
 /********** Global variables **********/
-extern count_t average;    /* average count */
-extern count_t max;        /* maximum count */
+extern count_t average;   /* average count */
+extern count_t max;       /* maximum count */
 /* Values for `type' */
-#define BYTES_TYPE     1
-#define PACKETS_TYPE   2
+#define BYTES_TYPE      0
+#define PACKETS_TYPE    1
 extern int type;           /* What kind of data is gathered */
-/* Values for `where' */
-#define IP_ACCT    1
-#define DEV        2
-extern int where;          /* Where to gather data from. */
 
 /********** Functions **********/
 
@@ -70,10 +78,10 @@ extern void report_error(char *msg);
 
 /* Initialize the data gathering process. Sets the variables `type' and
    `where', for future reference. Returns `type' */
-extern int initialize(char *iface, int try_ip_acct);
+extern int initialize(char *iface, int num_avg/*  , int kb */);
 extern int cleanup(void);
 
 /* Read the new counts and update the `average' and `max'. */
-extern void update_avg(void);
+extern void update_avg(int seconds);
 
 #endif /* _DATA_H */
